const path = require('path')
const fs = require('fs-extra')
const utils = require('./utils')
const prompt = require('prompt-sync')()
module.exports = (projPaths, publish) => {
    const componentConfig = require(projPaths.jsonSrc)
    const name = componentConfig.name
    const preVersion = componentConfig.version
    let version
    if (publish) {
        const nextVersion = utils.version.up(componentConfig.version, '0.0.1')

        version = (
            prompt(`version: (${nextVersion} or ${preVersion} < ) `) || ''
        ).trim()
        if (!version) {
            version = nextVersion
        }

        version = utils.version.trim(version)

        if (
            utils.version.lt(version, preVersion) ||
            utils.version.eq(version, preVersion)
        ) {
            console.error(`请输入大于 ${preVersion} 的版本号`.red)
            return
        }

        componentConfig.version = version
    }

    const distPath = projPaths.dist

    if (!fs.existsSync(distPath)) {
        console.error(`请先 'yarn build' 构建组件`.red)
        return
    }

    const packageJson = { ...componentConfig }
    delete packageJson.extract
    delete packageJson.externals
    delete packageJson.sourceMap

    packageJson.name = componentConfig.scope
        ? '@' + componentConfig.scope + '/' + name
        : name
    packageJson.main = 'index.js'

    fs.outputJsonSync(projPaths.jsonDist, packageJson, {
        encoding: 'utf8'
    })
    if (publish) {
        const comJson = fs.readFileSync(projPaths.jsonSrc, 'utf8')
        fs.outputFileSync(
            projPaths.jsonSrc,
            comJson.replace(preVersion, version)
        )
    }
}
