require('colors')
const path = require('path')
const fs = require('fs-extra')
const shell = require('shelljs')
const prompt = require('prompt-sync')()
const argv = require('yargs').argv
const utils = require('./common/utils')
const coconfig = require('./common/co-config')
const basePath = process.cwd()

if (coconfig.setting.name && coconfig.setting.single) {
    console.error('单组件项目不可重复创建组件'.red)
    return
}
const isSingle = !(argv.m || argv.multiple)

const name = (prompt('component name:') || '').trim()
if (!name) {
    console.error('请输入组件名'.red)
    return
}

const projPaths = require('./common/project-paths')(name, isSingle)

const srcPath = projPaths.src

if (fs.existsSync(srcPath)) {
    console.error(`已存在同名组件 ${srcPath}， 请给组件一个新名字`.red)
    return
}

let scope = (
    prompt(
        `scope: ${
            coconfig.setting.scope ? '(' + coconfig.setting.scope + ')' : ''
        }`
    ) || ''
).trim()
if (!scope) {
    scope = coconfig.setting.scope || ''
}

let desc = (prompt('description:') || '').trim()
if (!desc) {
    desc = ''
}

let version = (prompt('version: (0.1 or 0.1.0) ') || '').trim()
if (!version) {
    version = '0.1'
}
if (!utils.version.valid(version)) {
    console.error('请输入正确的版本号，如：0.0.1 或 0.1'.red)
    return
}

version = utils.version.trim(version)

const info = {
    name,
    scopeName: '@' + scope + '/' + name,
    desc,
    scope,
    version
}
;(async () => {
    await fs.copySync(
        path.resolve(__dirname, 'template/demo'),
        projPaths.demoSrc
    )
    await fs.copySync(path.resolve(__dirname, 'template/test'), projPaths.test)
    await fs.copySync(
        path.resolve(__dirname, 'template/types'),
        projPaths.typesSrc
    )
    await fs.copySync(
        path.resolve(__dirname, 'template/component.json'),
        projPaths.jsonSrc
    )
    await fs.copySync(
        path.resolve(__dirname, 'template/index.js'),
        projPaths.indexJs
    )
    await fs.copySync(
        path.resolve(__dirname, 'template/index.vue'),
        projPaths.indexVue
    )
    await fs.copySync(
        path.resolve(__dirname, 'template/README.md'),
        projPaths.readmeSrc
    )
    await fs.copySync(
        path.resolve(__dirname, 'template/types'),
        projPaths.typesSrc
    )

    utils.fileReplace(projPaths.jsonSrc, info)
    utils.fileReplace(projPaths.readmeSrc, info)
    utils.fileReplace(path.resolve(projPaths.typesSrc, 'index.d.ts'), info)

    if (coconfig.isNewProject) {
        shell.cd(projPaths.root)
        const { code, stderr, stdout } = shell.exec('npm install')
    }

    console.log('组件创建成功！'.green)
})()

coconfig.save({
    name,
    scope,
    single: isSingle
})
