const utils = require('../common/webpack-utils')
const merge = require('webpack-merge')
const baseWebpackConfig = require('./base')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const OptimizeCSSPlugin = require('optimize-css-assets-webpack-plugin')
const path = require('path')
module.exports = (componentName) => {
    const projPaths = require('../common/project-paths')(componentName)
    const srcPath = projPaths.src
    const distPath = projPaths.dist

    let componentConfig = projPaths.jsonSrc

    componentConfig = Object.assign(
        {
            sourceMap: false,
            extract: true,
            externals: {}
        },
        componentConfig
    )
    Object.assign(componentConfig.externals, {
        'element-ui': 'element-ui',
        vue: {
            root: 'Vue',
            commonjs: 'vue',
            commonjs2: 'vue',
            amd: 'vue'
        }
    })

    const entry = { index: path.join(srcPath, 'index.js') }

    console.log(srcPath, '---', distPath)
    return merge(baseWebpackConfig, {
        mode: 'production',
        entry,
        module: {
            rules: utils.styleLoaders({
                sourceMap: componentConfig.sourceMap,
                extract: !!componentConfig.extract
            })
        },
        devtool: false,
        output: {
            path: distPath,
            publicPath: '',
            filename: `index.js`,
            library: componentConfig.scope
                ? '@' + componentConfig.scope + '/' + componentName
                : componentName,
            libraryTarget: 'umd',
            umdNamedDefine: true
        },
        devtool: componentConfig.sourceMap ? '#source-map' : false,
        externals: componentConfig.externals,
        plugins: [
            new MiniCssExtractPlugin({
                filename: `index.css`
            }),
            new OptimizeCSSPlugin()
        ]
    })
}
