const rimraf = require('rimraf')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const utils = require('../common/webpack-utils')
const merge = require('webpack-merge')
const baseWebpackConf = require('./base')

const path = require('path')
const fs = require('fs')

module.exports = (componentName) => {
    const projPaths = require('../common/project-paths')(componentName)
    const srcPath = projPaths.src
    const distPath = projPaths.dist
    const demoPath = projPaths.demoDist
    let templatePath = path.join(__dirname, '../common/demo-tpl.html')

    const entry = { index: path.join(projPaths.demoSrc, 'index.js') },
        plugins = [
            new HtmlWebpackPlugin({
                title: componentName,
                cache: false,
                filename: `index.html`,
                inject: 'body',
                template: templatePath
            }),
            new MiniCssExtractPlugin({
                filename: '[name].css'
            })
        ]
    const css = path.join(distPath, `index.css`)
    const js = path.join(distPath, `index.js`)
    return merge(baseWebpackConf, {
        entry,
        resolve: {
            alias: {
                CurrentComponent: js,
                'CurrentComponent-css': fs.existsSync(css)
                    ? css
                    : path.join(__dirname, '../common/placeholder.css')
            }
        },
        module: {
            rules: utils.styleLoaders({
                sourceMap: true,
                extract: true
            })
        },
        output: {
            path: demoPath,
            filename: '[name].js'
        },
        devtool: '#source-map',
        mode: 'development',
        plugins
    })
}
