const HtmlWebpackPlugin = require('html-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const wUtils = require('../common/webpack-utils')
const merge = require('webpack-merge')
const webpack = require('webpack')
const baseWebpackConf = require('./base')
const path = require('path')

module.exports = function(componentName) {
    const projPaths = require('../common/project-paths')(componentName)
    const srcPath = projPaths.src
    const demoPath = projPaths.demoDist

    let templatePath = path.join(__dirname, '../common/demo-tpl.html')

    return merge(baseWebpackConf, {
        entry: {
            index: [
                'webpack-dev-server/client?http://localhost:3333/',
                path.join(projPaths.demoSrc, 'index.js')
            ]
        },
        resolve: {
            alias: {
                CurrentComponent: path.join(srcPath, 'index.js'),
                'CurrentComponent-css': path.join(
                    __dirname,
                    '../common/placeholder.css'
                )
            }
        },
        module: {
            rules: wUtils.styleLoaders({
                sourceMap: true,
                extract: true
            })
        },
        output: {
            path: demoPath,
            filename: '[name].js'
        },
        devtool: '#source-map',
        watch: true,
        mode: 'development',
        devServer: {
            contentBase: demoPath,
            host: 'localhost',
            port: 3333,
            open: true
        },
        plugins: [
            new HtmlWebpackPlugin({
                title: componentName,
                cache: false,
                filename: `index.html`,
                inject: 'body',
                template: templatePath
            }),
            new MiniCssExtractPlugin({
                filename: '[name].css'
            }),
            new webpack.HotModuleReplacementPlugin()
        ]
    })
}
